Module: Aws::Polly

Defined in:
lib/aws-sdk-polly/event_streams.rb,
lib/aws-sdk-polly/presigner.rb,
lib/aws-sdk-polly/client_api.rb,
lib/aws-sdk-polly/async_client.rb,
lib/aws-sdk-polly/customizations.rb,
lib/aws-sdk-polly/endpoint_provider.rb,
lib/aws-sdk-polly/plugins/endpoints.rb,
lib/aws-sdk-polly/endpoint_parameters.rb,
lib/aws-sdk-polly/endpoints.rb,
lib/aws-sdk-polly/resource.rb,
lib/aws-sdk-polly/errors.rb,
lib/aws-sdk-polly/client.rb,
lib/aws-sdk-polly/types.rb,
lib/aws-sdk-polly.rb

Overview

This module provides support for Amazon Polly. This module is available in the ‘aws-sdk-polly` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

polly = Aws::Polly::Client.new
resp = polly.delete_lexicon(params)

See Client for more information.

# Async Client

The AsyncClient class provides one asynchronous method for each API operation. Operation methods each accept a hash of request parameters and return an async response. For streaming operations, you can signal input events and register output event callbacks before waiting on the response.

polly = Aws::Polly::AsyncClient.new
resp = polly.delete_lexicon(
  # params and input stream
 ) do |output_stream|
  # register callbacks for events
end

See AsyncClient for more information.

# Errors

Errors returned from Amazon Polly are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::Polly::Errors::ServiceError
  # rescues all Amazon Polly API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, EventStreams, Plugins, Types Classes: AsyncClient, Client, EndpointParameters, EndpointProvider, Presigner, Resource

service collapse

GEM_VERSION =
'1.125.0'