Class: Aws::Polly::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Polly::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-polly/client.rb
Overview
An API client for Polly. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Polly::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_lexicon(params = {}) ⇒ Struct
Deletes the specified pronunciation lexicon stored in an Amazon Web Services Region.
-
#describe_voices(params = {}) ⇒ Types::DescribeVoicesOutput
Returns the list of voices that are available for use when requesting speech synthesis.
-
#get_lexicon(params = {}) ⇒ Types::GetLexiconOutput
Returns the content of the specified pronunciation lexicon stored in an Amazon Web Services Region.
-
#get_speech_synthesis_task(params = {}) ⇒ Types::GetSpeechSynthesisTaskOutput
Retrieves a specific SpeechSynthesisTask object based on its TaskID.
-
#list_lexicons(params = {}) ⇒ Types::ListLexiconsOutput
Returns a list of pronunciation lexicons stored in an Amazon Web Services Region.
-
#list_speech_synthesis_tasks(params = {}) ⇒ Types::ListSpeechSynthesisTasksOutput
Returns a list of SpeechSynthesisTask objects ordered by their creation date.
-
#put_lexicon(params = {}) ⇒ Struct
Stores a pronunciation lexicon in an Amazon Web Services Region.
-
#start_speech_synthesis_task(params = {}) ⇒ Types::StartSpeechSynthesisTaskOutput
Allows the creation of an asynchronous synthesis task, by starting a new ‘SpeechSynthesisTask`.
-
#synthesize_speech(params = {}) ⇒ Types::SynthesizeSpeechOutput
Synthesizes UTF-8 input, plain text or SSML, to a stream of bytes.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
484 485 486 |
# File 'lib/aws-sdk-polly/client.rb', line 484 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1267 1268 1269 |
# File 'lib/aws-sdk-polly/client.rb', line 1267 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1270 1271 1272 |
# File 'lib/aws-sdk-polly/client.rb', line 1270 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/aws-sdk-polly/client.rb', line 1240 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Polly') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-polly' context[:gem_version] = '1.124.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_lexicon(params = {}) ⇒ Struct
Deletes the specified pronunciation lexicon stored in an Amazon Web Services Region. A lexicon which has been deleted is not available for speech synthesis, nor is it possible to retrieve it using either the ‘GetLexicon` or `ListLexicon` APIs.
For more information, see [Managing Lexicons].
[1]: docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html
530 531 532 533 |
# File 'lib/aws-sdk-polly/client.rb', line 530 def delete_lexicon(params = {}, = {}) req = build_request(:delete_lexicon, params) req.send_request() end |
#describe_voices(params = {}) ⇒ Types::DescribeVoicesOutput
Returns the list of voices that are available for use when requesting speech synthesis. Each voice speaks a specified language, is either male or female, and is identified by an ID, which is the ASCII version of the voice name.
When synthesizing speech ( ‘SynthesizeSpeech` ), you provide the voice ID for the voice you want from the list of voices returned by `DescribeVoices`.
For example, you want your news reader application to read news in a specific language, but giving a user the option to choose the voice. Using the ‘DescribeVoices` operation you can provide the user with a list of available voices to select from.
You can optionally specify a language code to filter the available voices. For example, if you specify ‘en-US`, the operation returns a list of all available US English voices.
This operation requires permissions to perform the ‘polly:DescribeVoices` action.
648 649 650 651 |
# File 'lib/aws-sdk-polly/client.rb', line 648 def describe_voices(params = {}, = {}) req = build_request(:describe_voices, params) req.send_request() end |
#get_lexicon(params = {}) ⇒ Types::GetLexiconOutput
Returns the content of the specified pronunciation lexicon stored in an Amazon Web Services Region. For more information, see [Managing Lexicons].
[1]: docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html
715 716 717 718 |
# File 'lib/aws-sdk-polly/client.rb', line 715 def get_lexicon(params = {}, = {}) req = build_request(:get_lexicon, params) req.send_request() end |
#get_speech_synthesis_task(params = {}) ⇒ Types::GetSpeechSynthesisTaskOutput
Retrieves a specific SpeechSynthesisTask object based on its TaskID. This object contains information about the given speech synthesis task, including the status of the task, and a link to the S3 bucket containing the output of the task.
762 763 764 765 |
# File 'lib/aws-sdk-polly/client.rb', line 762 def get_speech_synthesis_task(params = {}, = {}) req = build_request(:get_speech_synthesis_task, params) req.send_request() end |
#list_lexicons(params = {}) ⇒ Types::ListLexiconsOutput
Returns a list of pronunciation lexicons stored in an Amazon Web Services Region. For more information, see [Managing Lexicons].
[1]: docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html
831 832 833 834 |
# File 'lib/aws-sdk-polly/client.rb', line 831 def list_lexicons(params = {}, = {}) req = build_request(:list_lexicons, params) req.send_request() end |
#list_speech_synthesis_tasks(params = {}) ⇒ Types::ListSpeechSynthesisTasksOutput
Returns a list of SpeechSynthesisTask objects ordered by their creation date. This operation can filter the tasks by their status, for example, allowing users to list only tasks that are completed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
891 892 893 894 |
# File 'lib/aws-sdk-polly/client.rb', line 891 def list_speech_synthesis_tasks(params = {}, = {}) req = build_request(:list_speech_synthesis_tasks, params) req.send_request() end |
#put_lexicon(params = {}) ⇒ Struct
Stores a pronunciation lexicon in an Amazon Web Services Region. If a lexicon with the same name already exists in the region, it is overwritten by the new lexicon. Lexicon operations have eventual consistency, therefore, it might take some time before the lexicon is available to the SynthesizeSpeech operation.
For more information, see [Managing Lexicons].
[1]: docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html
943 944 945 946 |
# File 'lib/aws-sdk-polly/client.rb', line 943 def put_lexicon(params = {}, = {}) req = build_request(:put_lexicon, params) req.send_request() end |
#start_speech_synthesis_task(params = {}) ⇒ Types::StartSpeechSynthesisTaskOutput
Allows the creation of an asynchronous synthesis task, by starting a new ‘SpeechSynthesisTask`. This operation requires all the standard information needed for speech synthesis, plus the name of an Amazon S3 bucket for the service to store the output of the synthesis task and two optional parameters (`OutputS3KeyPrefix` and `SnsTopicArn`). Once the synthesis task is created, this operation will return a `SpeechSynthesisTask` object, which will include an identifier of this task as well as the current status. The `SpeechSynthesisTask` object is available for 72 hours after starting the asynchronous synthesis task.
1076 1077 1078 1079 |
# File 'lib/aws-sdk-polly/client.rb', line 1076 def start_speech_synthesis_task(params = {}, = {}) req = build_request(:start_speech_synthesis_task, params) req.send_request() end |
#synthesize_speech(params = {}) ⇒ Types::SynthesizeSpeechOutput
Synthesizes UTF-8 input, plain text or SSML, to a stream of bytes. SSML input must be valid, well-formed SSML. Some alphabets might not be available with all the voices (for example, Cyrillic might not be read at all by English voices) unless phoneme mapping is used. For more information, see [How it Works].
[1]: docs.aws.amazon.com/polly/latest/dg/how-text-to-speech-works.html
1231 1232 1233 1234 |
# File 'lib/aws-sdk-polly/client.rb', line 1231 def synthesize_speech(params = {}, = {}, &block) req = build_request(:synthesize_speech, params) req.send_request(, &block) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1260 1261 1262 |
# File 'lib/aws-sdk-polly/client.rb', line 1260 def waiter_names [] end |