Class: Aws::Polly::EventStreams::StartSpeechSynthesisStreamActionStream

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-polly/event_streams.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeStartSpeechSynthesisStreamActionStream

Returns a new instance of StartSpeechSynthesisStreamActionStream.



14
15
16
# File 'lib/aws-sdk-polly/event_streams.rb', line 14

def initialize
  @event_emitter = Aws::EventEmitter.new
end

Instance Attribute Details

#event_emitterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns Aws::EventEmitter.

Returns:

  • Aws::EventEmitter



45
46
47
# File 'lib/aws-sdk-polly/event_streams.rb', line 45

def event_emitter
  @event_emitter
end

Instance Method Details

#signal_close_stream_event_event(params = {}) ⇒ Object

This event has no members



35
36
37
# File 'lib/aws-sdk-polly/event_streams.rb', line 35

def signal_close_stream_event_event(params = {})
  @event_emitter.emit(:close_stream_event, params)
end

#signal_end_streamObject



39
40
41
# File 'lib/aws-sdk-polly/event_streams.rb', line 39

def signal_end_stream
  @event_emitter.emit(:end_stream, {})
end

#signal_text_event_event(params = {}) ⇒ Object

Parameters:

  • params (Hash) (defaults to: {})

    a customizable set of options

Options Hash (params):

  • :text (String)

    The text content to synthesize. If you specify ‘ssml` as the `TextType`, follow the SSML format for the input text.

  • :text_type (String)

    Specifies whether the input text is plain text or SSML. Default: plain text.

  • :flush_stream_configuration (Types::FlushStreamConfiguration)

    Configuration for controlling when synthesized audio flushes to the output stream.



30
31
32
# File 'lib/aws-sdk-polly/event_streams.rb', line 30

def signal_text_event_event(params = {})
  @event_emitter.emit(:text_event, params)
end