Class: Aws::Polly::Types::StartSpeechSynthesisStreamActionStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-polly/types.rb

Overview

Inbound event stream for sending input and control events to manage bidirectional speech synthesis.

EventStream is an Enumerator of Events.

#event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



1366
1367
1368
1369
1370
1371
# File 'lib/aws-sdk-polly/types.rb', line 1366

def event_types
  [
    :text_event,
    :close_stream_event
  ]
end