Method: Aws::Polly::Types::SynthesisTask#engine

Defined in:
lib/aws-sdk-polly/types.rb

#engineString

Specifies the engine (standard, neural, long-form or generative) for Amazon Polly to use when processing input text for speech synthesis. Using a voice that is not supported for the engine selected will result in an error.

Returns:

  • (String)


787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
# File 'lib/aws-sdk-polly/types.rb', line 787

class SynthesisTask < Struct.new(
  :engine,
  :task_id,
  :task_status,
  :task_status_reason,
  :output_uri,
  :creation_time,
  :request_characters,
  :sns_topic_arn,
  :lexicon_names,
  :output_format,
  :sample_rate,
  :speech_mark_types,
  :text_type,
  :voice_id,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end