Class: Aws::Polly::Types::SynthesizeSpeechInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Polly::Types::SynthesizeSpeechInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-polly/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine ⇒ String
Specifies the engine (
standard,neural,long-form, orgenerative) for Amazon Polly to use when processing input text for speech synthesis. -
#language_code ⇒ String
Optional language code for the Synthesize Speech request.
-
#lexicon_names ⇒ Array<String>
List of one or more pronunciation lexicon names you want the service to apply during synthesis.
-
#output_format ⇒ String
The format in which the returned output will be encoded.
-
#sample_rate ⇒ String
The audio frequency specified in Hz.
-
#speech_mark_types ⇒ Array<String>
The type of speech marks returned for the input text.
-
#text ⇒ String
Input text to synthesize.
-
#text_type ⇒ String
Specifies whether the input text is plain text or SSML.
-
#voice_id ⇒ String
Voice ID to use for the synthesis.
Instance Attribute Details
#engine ⇒ String
Specifies the engine (standard, neural, long-form, or
generative) for Amazon Polly to use when processing input text for
speech synthesis. Provide an engine that is supported by the voice
you select. If you don't provide an engine, the standard engine is
selected by default. If a chosen voice isn't supported by the
standard engine, this will result in an error. For information on
Amazon Polly voices and which voices are available for each engine,
see Available Voices.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
Optional language code for the Synthesize Speech request. This is only necessary if using a bilingual voice, such as Aditi, which can be used for either Indian English (en-IN) or Hindi (hi-IN).
If a bilingual voice is used and no language code is specified,
Amazon Polly uses the default language of the bilingual voice. The
default language for any voice is the one returned by the
DescribeVoices operation for the LanguageCode parameter. For
example, if no language code is specified, Aditi will use Indian
English rather than Hindi.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#lexicon_names ⇒ Array<String>
List of one or more pronunciation lexicon names you want the service to apply during synthesis. Lexicons are applied only if the language of the lexicon is the same as the language of the voice. For information about storing lexicons, see PutLexicon.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#output_format ⇒ String
The format in which the returned output will be encoded. For audio stream, this will be mp3, ogg_vorbis, ogg_opus, mu-law, a-law or pcm. For speech marks, this will be json.
When pcm is used, the content returned is audio/pcm in a signed 16-bit, 1 channel (mono), little-endian format.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ String
The audio frequency specified in Hz.
The valid values for mp3 and ogg_vorbis are "8000", "16000", "22050", "24000", "44100" and "48000". The default value for standard voices is "22050". The default value for neural voices is "24000". The default value for long-form voices is "24000". The default value for generative voices is "24000".
Valid values for pcm are "8000" and "16000" The default value is "16000".
Valid value for ogg_opus is "48000".
Valid value for mu-law and a-law is "8000".
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#speech_mark_types ⇒ Array<String>
The type of speech marks returned for the input text.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
Input text to synthesize. If you specify ssml as the TextType,
follow the SSML format for the input text.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#text_type ⇒ String
Specifies whether the input text is plain text or SSML. The default value is plain text. For more information, see Using SSML.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |
#voice_id ⇒ String
Voice ID to use for the synthesis. You can get a list of available voice IDs by calling the DescribeVoices operation.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-polly/types.rb', line 1084 class SynthesizeSpeechInput < Struct.new( :engine, :language_code, :lexicon_names, :output_format, :sample_rate, :speech_mark_types, :text, :text_type, :voice_id) SENSITIVE = [] include Aws::Structure end |